@@ -1,7 +1,7 @@
 import logging
-from atlassian import AtlassianRestAPI
+from .rest_client import AtlassianRestAPI
 
-log = logging.getLogger('atlassian.stash')
+log = logging.getLogger(__name__)
 
 
 class Bamboo(AtlassianRestAPI):
@@ -18,8 +18,9 @@ class Bamboo(AtlassianRestAPI):
         params.update(kwargs)
         return self.get(self.resource_url(resource), flags=flags, params=params)
 
-    def projects(self, expand=None, favourite=False, cloverEnabled=False, start_index=0, max_results=25):
-        return self.base_list_call('project', expand, favourite, cloverEnabled, start_index, max_results)
+    def projects(self, project_key=None, expand=None, favourite=False, cloverEnabled=False, start_index=0, max_results=25):
+        resource = 'project/{}'.format(project_key) if project_key else 'project'
+        return self.base_list_call(resource, expand, favourite, cloverEnabled, start_index, max_results)
 
     def plans(self, expand=None, favourite=False, cloverEnabled=False, start_index=0, max_results=25):
         return self.base_list_call("plan", expand, favourite, cloverEnabled, start_index, max_results)
@@ -108,3 +109,32 @@ class Bamboo(AtlassianRestAPI):
 
     def server_info(self):
         return self.get(self.resource_url('info'))
+
+    def agent_status(self):
+        return self.get(self.resource_url('agent'))
+
+    def activity(self):
+        return self.get('build/admin/ajax/getDashboardSummary.action')
+
+    def deployment_project(self, project_id=None):
+        resource = 'deploy/project/{}'.format(project_id) if project_id else 'deploy/project/all'
+        return self.get(self.resource_url(resource))
+
+    def deployment_environment_results(self, env_id, expand=None):
+        resource = 'deploy/environment/{environmentId}/results'.format(environmentId=env_id)
+        params = {'expand': expand}
+        return self.get(self.resource_url(resource), params=params)
+
+    def deployment_dashboard(self, project_id=None):
+        """
+        Returns the current status of each deployment environment
+        If no project id is provided, returns all projects.
+        """
+        resource = 'deploy/dashboard/{}'.format(project_id) if project_id else 'deploy/dashboard'
+        return self.get(self.resource_url(resource))
+
+    def search_branches(self, plan_key, include_default_branch=True, start_index=0, max_results=25):
+        return self.base_list_call('search/branches', expand=None, start_index=start_index, max_results=max_results,
+                                   cloverEnabled=False, favourite=False,
+                                   masterPlanKey=plan_key,
+                                   includeMasterBranch=include_default_branch)
